# Flow python client

A python client for the Flow API.

## Installation

First, install [python](https://www.python.org/downloads/) and [poetry](https://python-poetry.org/docs/#installing-with-the-official-installer).

Then, clone the repository, create a virtual environment, and install the dependencies.
    
```bash
git clone
cd flow-python-client
python -m venv venv
source venv/bin/activate
poetry install
```
